# October 26, 2021

**Date:** October 26, 2021, at 8am Pacific (your [timezone](https://arewemeetingyet.com/Los%20Angeles/2021-10-26/8:00/Jupyter%20Community%20Call))

**[Discourse](https://discourse.jupyter.org/t/jupyter-community-calls/668)**

**[YouTube link](https://youtu.be/ik2hG10GlE4)** 

**Please note:**
- Community calls are recorded and posted to this [playlist](https://www.youtube.com/playlist?list=PLUrHeD2K9Cmkoamm4NjLmvXC4Y6E1o8SP)
- These notes will be recorded and posted [here](https://jupyter.readthedocs.io/en/latest/community/community-call-notes/index.html)
- Everyone present is held to the [Jupyter Code of Conduct](https://jupyter.org/conduct)

## Purpose

Think of it as a monthly, virtual JupyterCon. It’s a place to announce and share fun things happening in the Jupyter community.

For more discussion on the format of these calls, see the thread [here](https://discourse.jupyter.org/t/reviving-the-all-jupyter-team-meetings/423).

## Short reports, celebrations, shout-outs

* **Carol** Thank you Zach for getting discussion started about [Classic notebook and maintainer issues on GitHub](https://github.com/jupyter/notebook/issues/6210). :heart: 
* **Rollin** Reminder that Jupyter security calls are on every other Friday ([see community calendar](https://jupyter.readthedocs.io/en/latest/community/content-community.html#jupyter-community-meetings))
* **Many people** Thank you Darian for years of sustained effort on improving governance!

## Agenda Items

* **Rollin** Jupyter security group overview and updates
* **Chris** [Executable book project](https://executablebooks.org/en/latest) updates
* **Simon** [BinderHub updates](https://github.com/jupyterhub/jupyterhub/blob/main/docs/source/changelog.md)
* **Tony** exploring a 7-year old notebook
* **Zach** exploring an 8-year old notebook
* **Darian and Fernando** Update on governance refactor - parts that are now active or coming.
    * Relevant PR [jupyter/governance #103](https://github.com/jupyter/governance/pull/103)
    * [Slides](https://docs.google.com/presentation/d/1Soa1Cm23WmQ6KOUAvLXzXhe2aE7jmf3vdR84oTd7QPs/edit#slide=id.p)

## Other Links Shared

This is a space to store links shared during community call discussions related to or separate from the agenda items.

- [jupyterlab/jupyterlab #11079](https://github.com/jupyterlab/jupyterlab/pull/11079) Settings UI PR
- [myst](https://myst-parser.readthedocs.io/)
- [The Executable Book Project gallery](https://executablebooks.org/en/latest/gallery.html)
- [Sphinx autoapi](https://sphinx-autoapi.readthedocs.io/)
- [2i2c](https://2i2c.org/)
- [San Diego Python Intro to Python](https://github.com/sandiegopython/intro-to-python)
- [Carol's Journey to Jupyter slides](https://www.slideshare.net/willingc/journey-to-jupyter)
- [papyri](https://github.com/Carreau/papyri)
- [Carol's JupyterHub "A Thing Explainer" slides](https://www.slideshare.net/willingc/jupyterhub-a-thing-explainer-overview)
- https://abigayle-mercer.github.io/Jupyter/CH_3-1.html
- [Jupyter governance office hours on the Jupyter Discourse](https://discourse.jupyter.org/t/governance-office-hours-meeting-minutes/1480/161) 
- [Notebook Hall of Fame](https://github.com/jennalandy/notebook-research/blob/master/analysis_notebooks/16_HallOfFame.ipynb)

## Attendees 

|   Name   |           Institution     | GitHub Handle                     |
|----------|---------------------------|-----------------------------------|
|     Fernando Pérez     |     UC Berkeley, Jupyter       | fperez
| Simon Li | University of Dundee | @manics
| Rollin Thomas         | NERSC           | @rcthomas
| Carol Willing | Noteable | @willingc  
| Gabriel Fouasnon         | Quansight Labs           | gabalafou 
|   Alex Bozarth       |      IBM      | @ajbozarth
|  Karla Spuldaro        |   IBM         | @karlaspuldaro |
| Chris Sewell | Executablebooks | @chrisjsewell |
|Jared Thompson|Comcast|@afonit|
| Loic Huder        | ESRF            | @loichuder |
| tonyfast | quansight | @tonyfast |
| Isabela Presedo-Floyd | Quansight Labs | @isabela-pf |

Plus 4 more